==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/igr-annotation-layer.js <==
import { __extends } from "tslib";
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint, ensureEnum, toDoubleCollection, fromDoubleCollection } from "igniteui-react-core";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
var IgrAnnotationLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrAnnotationLayer, _super);
    function IgrAnnotationLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnnotationLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useIndex", {
        /**
         * Gets or sets whether this series should take up an index for auto brush coloring.
        */
        get: function () {
            return this.i.un;
        },
        set: function (v) {
            this.i.un = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useLegend", {
        /**
         * Gets or sets whether this series interacts with the chart legend.
        */
        get: function () {
            return this.i.uo;
        },
        set: function (v) {
            this.i.uo = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "cursorPosition", {
        /**
         * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
         * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
        */
        get: function () {
            return fromPoint(this.i.wy);
        },
        set: function (v) {
            this.i.wy = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairDisabled", {
        /**
         * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
        */
        get: function () {
            return this.i.ui;
        },
        set: function (v) {
            this.i.ui = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairBehaviorDisabled", {
        /**
         * Gets whether or not the default crosshair behavior is disabled.
        */
        get: function () {
            return this.i.ef;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "appearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.t4;
        },
        set: function (v) {
            this.i.t4 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.t1;
        },
        set: function (v) {
            this.i.t1 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.u1;
        },
        set: function (v) {
            this.i.u1 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.uq;
        },
        set: function (v) {
            this.i.uq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.ub;
        },
        set: function (v) {
            this.i.ub = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.t2;
        },
        set: function (v) {
            this.i.t2 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.uc;
        },
        set: function (v) {
            this.i.uc = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.t3;
        },
        set: function (v) {
            this.i.t3 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.u0;
        },
        set: function (v) {
            this.i.u0 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.up;
        },
        set: function (v) {
            this.i.up = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.u2;
        },
        set: function (v) {
            this.i.u2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.ur;
        },
        set: function (v) {
            this.i.ur = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.wv);
        },
        set: function (v) {
            this.i.wv = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.wp);
        },
        set: function (v) {
            this.i.wp = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.ww);
        },
        set: function (v) {
            this.i.ww = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.wq);
        },
        set: function (v) {
            this.i.wq = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isIndexed", {
        /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
        get: function () {
            return this.i.et;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isUsableInLegend", {
        /**
         * Gets if the series should appear in any legends.
        */
        get: function () {
            return this.i.isUsableInLegend;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isAnnotationLayer", {
        /**
         * Gets whether this series is an annotation layer.
        */
        get: function () {
            return this.i.d6;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shouldRenderAsOverlay", {
        /**
         * Gets or sets whether this layer renders as an overlay or not.
        */
        get: function () {
            return this.i.um;
        },
        set: function (v) {
            this.i.um = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrAnnotationLayer;
}(IgrSeries));
export { IgrAnnotationLayer };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/igr-annotation-layer.js <==
import { __extends } from "tslib";
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint, ensureEnum, toDoubleCollection, fromDoubleCollection } from "igniteui-react-core";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
var IgrAnnotationLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrAnnotationLayer, _super);
    function IgrAnnotationLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnnotationLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useIndex", {
        /**
         * Gets or sets whether this series should take up an index for auto brush coloring.
        */
        get: function () {
            return this.i.xf;
        },
        set: function (v) {
            this.i.xf = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useLegend", {
        /**
         * Gets or sets whether this series interacts with the chart legend.
        */
        get: function () {
            return this.i.xg;
        },
        set: function (v) {
            this.i.xg = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "cursorPosition", {
        /**
         * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
         * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
        */
        get: function () {
            return fromPoint(this.i.zq);
        },
        set: function (v) {
            this.i.zq = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairDisabled", {
        /**
         * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
        */
        get: function () {
            return this.i.xa;
        },
        set: function (v) {
            this.i.xa = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairBehaviorDisabled", {
        /**
         * Gets whether or not the default crosshair behavior is disabled.
        */
        get: function () {
            return this.i.e0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "appearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.ww;
        },
        set: function (v) {
            this.i.ww = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wt;
        },
        set: function (v) {
            this.i.wt = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xt;
        },
        set: function (v) {
            this.i.xt = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xi;
        },
        set: function (v) {
            this.i.xi = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.w3;
        },
        set: function (v) {
            this.i.w3 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wu;
        },
        set: function (v) {
            this.i.wu = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.w4;
        },
        set: function (v) {
            this.i.w4 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wv;
        },
        set: function (v) {
            this.i.wv = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xs;
        },
        set: function (v) {
            this.i.xs = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xh;
        },
        set: function (v) {
            this.i.xh = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xu;
        },
        set: function (v) {
            this.i.xu = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xj;
        },
        set: function (v) {
            this.i.xj = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zn);
        },
        set: function (v) {
            this.i.zn = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zh);
        },
        set: function (v) {
            this.i.zh = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zo);
        },
        set: function (v) {
            this.i.zo = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zi);
        },
        set: function (v) {
            this.i.zi = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isIndexed", {
        /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
        get: function () {
            return this.i.ff;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isUsableInLegend", {
        /**
         * Gets if the series should appear in any legends.
        */
        get: function () {
            return this.i.isUsableInLegend;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isAnnotationLayer", {
        /**
         * Gets whether this series is an annotation layer.
        */
        get: function () {
            return this.i.er;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shouldRenderAsOverlay", {
        /**
         * Gets or sets whether this layer renders as an overlay or not.
        */
        get: function () {
            return this.i.xe;
        },
        set: function (v) {
            this.i.xe = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrAnnotationLayer;
}(IgrSeries));
export { IgrAnnotationLayer };
